#<
# Log
#
# DESCRIPTION
#  Base ten logarithm of absolute values.
#
# USAGE
#       <in.H  Log  [range=3 centered=2] > out.H
#
# INPUT PARAMETERS
#	range   -real       defines the smallest allowed value.
#                     Defining max to be the maximum of the logs (best 
#                     signal), output values (bad signal) below (max-range) 
#                     are set to (max-range). Often you might choose range
#                     to be a small integer, for example, range=3 means
#                     each input handled as max(input, biggest/1000).
#
#  centered -integer  defines method of shifting mean of log.
#                     0-The max is subtracted so all logs are negative.
#                       label2="log base 10" is putched
#                     1- The average of max and (max-range) is subtracted.
#                       (effectively scaling the original data)
#                       pclip=100 is putched.
#                     2-The average value of all the logs is subtracted.
#                       range=2*(max-avg) is putched.
# CATEGORY
# seplib seis program
#>
#
# KEYWORDS      log logarithm
#
# WHERE
#       ./cube/seis/Log.rs
#
#%
# author:	Claerbout and Harlan	8/9/89
# jon 8-10-93	added tomography centering.  set default range=3
                integer n1, n2, n3, esize, n
from history:	integer n1, n2, n3, esize
if (esize !=4)	call erexit('esize != 4')
allocate:	real x(n1,n2,n3), g(n1,n2,n3)
n = n1*n2*n3

subroutine mylog( n, x, g)
integer i,n, centered
real x(n), g(n), scale, big, small, avg, range
from par:	integer centered=2
from par:	real	range=3

call sreed('in', x, 4*n)
do i=1,n
	x(i) = abs(x(i))
scale = alog(10.)
do i=1, n
	g(i) = alog( x(i) +1.e-35) / scale
big = g(1)
do i=1,n
	if(g(i) > big)
		big = g(i)
do i=1,n
	if( g(i) < (big-range) )
		g(i) = big-range
if( centered == 0 ) {
	do i=1,n
		g(i) = g(i) - big
	call putch('label2', 's','log base 10')
	}
if( centered == 1) {
	avg = (big + (big-range)) / 2.
	do i=1,n
		g(i) = g(i) - avg
	call putch('pclip', 'i',100)
	}
if( centered == 2) {
	avg = 0.
	do i=1,n
		avg = avg + g(i)
	avg = avg / n
	do i=1,n
		g(i) = g(i) - avg
	call putch( 'range', 'r', 2.*(big-avg) )
	}
call hclose()
call srite( 'out', g, n*4)
return;	end
